# django edict
#### Brandon R. Stoner <monokrome@monokro.me>

## What is this?

A django application for posting news. This is a fairly decent *news or
blogging* application, and easily provides features like comments, markup,
and RSS and ATOM feeds at no cost. However it makes no assumptions regarding
your design, and therefore doesn't include any WYSIWYG/WYSIWYM editors or
anything like that. You can easily add your own by simply applying it to
<textarea> elements with a 'text-edit' class. This application also ties into
the django user authentication system to allow multiple users to post, edit,
and delete news articles on the web site.

